# eric7.WebBrowser.CookieJar

Package implementing a cookie jar and related dialogs with models.

### Modules

CookieExceptionsModel | Module implementing the cookie exceptions model.
CookieJar | Module implementing a QNetworkCookieJar subclass with various accept policies.
CookiesConfigurationDialog | Module implementing the cookies configuration dialog.
CookiesDialog | Module implementing a dialog to show all cookies.
CookiesExceptionsDialog | Module implementing a dialog for the configuration of cookie exceptions.